@@ -13,14 +13,16 @@
 """Unit test for the Time datatypes."""
 
 from __future__ import print_function
+from __future__ import absolute_import
 
 import numpy
 
 import tables
 from tables.tests import common
 from tables.tests.common import allequal
-from tables.tests.common import unittest
+from tables.tests.common import unittest, test_filename
 from tables.tests.common import PyTablesTestCase as TestCase
+from six.moves import range
 
 
 class LeafCreationTestCase(common.TempFileMixin, TestCase):
@@ -408,7 +410,7 @@ class BigEndianTestCase(TestCase):
 
     def setUp(self):
         super(BigEndianTestCase, self).setUp()
-        filename = self._testFilename('times-nested-be.h5')
+        filename = test_filename('times-nested-be.h5')
         self.h5file = tables.open_file(filename, 'r')
 
     def tearDown(self):
